@@ -1,4 +1,4 @@
-from typing import Any
+from typing import Any, BinaryIO, Optional
 
 from .model import BaiDuResponse
 from .network import HandOver
@@ -8,14 +8,17 @@ class BaiDu(HandOver):
     def __init__(self, **request_kwargs: Any):
         super().__init__(**request_kwargs)
 
-    async def search(self, url: str) -> BaiDuResponse:
+    async def search(
+        self, url: Optional[str] = None, file: Optional[BinaryIO] = None
+    ) -> BaiDuResponse:
         params = {"from": "pc"}
         files = None
-        if url.startswith("http"):  # 网络url
+        if url:
             params["image"] = url
+        elif file:
+            files = {"image": file}
         else:
-            # 上传文件
-            files = {"image": open(url, "rb")}
+            raise ValueError("url or file is required")
         resp = await self.post(
             "https://graph.baidu.com/upload", params=params, files=files
         )
